﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Emgu.CV;
using Emgu.CV.Structure;
using FeatureDetectors;

namespace features {
	public partial class MDIChildForm : Form {
		public Emgu.CV.Image<Gray, Byte> image {get;private set;}
		public int mdiIndex = 0;
		public bool includeInList = false;
		public Results results;
		public ImageProperties imageProperties;
		public ToolStripMenuItem wndMenu;

		public MDIChildForm(Form MDIParent) {
			InitializeComponent();
			Init(MDIParent);
			imageProperties = new ImageProperties();
		}
		public MDIChildForm(Form MDIParent, string fileName) {
			InitializeComponent();
			imageProperties = new ImageProperties();
			loadImage(fileName);
			Init(MDIParent);
		}
		public MDIChildForm(Form MDIParent, Emgu.CV.Image<Bgr, Byte> img) {
			InitializeComponent();
			imageProperties = new ImageProperties();
			loadImage(img);
			Init(MDIParent);
		}
		public MDIChildForm(Form MDIParent, Emgu.CV.Image<Gray, Byte> img) {
			InitializeComponent();
			imageProperties = new ImageProperties();
			loadImage(img);
			Init(MDIParent);
		}
		public MDIChildForm(Form MDIParent, Emgu.CV.Image<Gray, Byte> img, ImageProperties imageProps) {
			InitializeComponent();
			imageProperties = imageProps.Clone();
			loadImage(img);
			Init(MDIParent);
		}
		private void Init(Form MDIParent) {
			this.MdiParent = MDIParent;
			this.mdiIndex = MDIParent.MdiChildren.Length - 1;
			this.Text = "PICTURE " + (this.mdiIndex + 1).ToString();

			wndMenu = ((MainForm) MDIParent).AddMdiMenu(this);
			this.Activate();

			
			this.Show();
		}
		public void loadImage(string fileName) {
			image = new Emgu.CV.Image<Gray, Byte>(fileName);
			imageProperties.GenerateImageId(image);
			reloadImage();
		}
		public void loadImage(Image<Gray, Byte> img) {
			image = img.Clone();
			imageProperties.GenerateImageId(image);
			reloadImage();
		}

		public void loadImage(Image<Bgr, Byte> img) {
			loadImage(img.Convert<Gray, byte>());
		}
		public void displayImage(Image<Bgr, Byte> img) {
			imageBox.Image = img;
		}
		public void reloadImage() {
			imageBox.Image = image;
		}

		private void includeImage_CheckedChanged(object sender, EventArgs e) {
			includeInList = includeImage.Checked;
		}
		public void SaveImages() {

			image.Save(Application.StartupPath + @"\images\" + 
						imageProperties.previousImageID +"-" +
						imageProperties.imageID + ".png");

			if (results != null) {
				this.imageBox.Image.Save(Application.StartupPath + @"\images\" + 
						imageProperties.previousImageID +"-" +
						imageProperties.imageID + "-"+ results.detectorName+"-" +results.detectorOptions.GetHash() +  ".png");
			}
		}

		private void MDIChildForm_FormClosed(object sender, FormClosedEventArgs e) {
			if (wndMenu!=null) wndMenu.Dispose();
		}
	}
}
